env = {'INDEX_TYPE': 'int32_t',
 'LAPACK': '0',
 'NO_KLU': '1',
 'NO_LAPACK': '0',
 'REAL_TYPE': 'double',
 'SUNDIALS_LIBS': 'sundials_cvodes,sundials_nvecserial',
 'SUNDIALS_PRECISION': 'double'}
